| Title: | LePage Type Tests |
|---|---|
| Description: | Location and scale hypothesis testing using the LePage test and variants of its as proposed by Hussain A. and Tsagris M. (2025), <doi:10.48550/arXiv.2509.19126>. |
| Authors: | Michail Tsagris [aut, cre], Abid Hussain [aut] |
| Maintainer: | Michail Tsagris <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0 |
| Built: | 2026-06-01 07:10:45 UTC |
| Source: | https://github.com/cran/LePage |
LePage type tests
| Package: | LePage |
| Type: | Package |
| Version: | 1.0 |
| Date: | 2025-09-25 |
| License: | GPL-2 |
Michail Tsagris <[email protected]>
Abid Hussain [email protected] and Michail Tsagris [email protected].
Hussain A. and Tsagris M. (2025). Modified Lepage-type test statistics for the weak null hypothesis. https://arxiv.org/pdf/2509.19126
Column-wise LePage type tests
col.lepage(x, y)col.lepage(x, y)
x |
A numerical matrix with data, where each column corresponds to the first sample. |
y |
A numerical matrix with data, where each column corresponds to the second sample. |
The classical LePage and 5 variants of it are performed, as proposed by Hussain and Tsagris (2025). The test is performed for each pair of columns of the x and y matrices, between the i-th column of and y.
A list including:
statistic |
A matrix with 6 columns, where each column contains each test statistic and each row refers to the pair of groups. |
pvalue |
A matrix with 6 columns, where each column contains each p-value and each row refers to the pair of groups. |
Abid Hussain and Michail Tsagris.
R implementation and documentation: Abid Hussain [email protected] and Michail Tsagris [email protected].
Hussain A. and Tsagris M. (2025). Modified Lepage-type test statistics for the weak null hypothesis. https://arxiv.org/pdf/2509.19126
x <- matrix( rnorm(30 * 5), ncol = 5 ) y <- matrix( rnorm(31 * 5), ncol = 5 ) col.lepage(x, y)x <- matrix( rnorm(30 * 5), ncol = 5 ) y <- matrix( rnorm(31 * 5), ncol = 5 ) col.lepage(x, y)
LePage type tests
lepage(x, y)lepage(x, y)
x |
A numerical vector with data of the first sample. |
y |
A numerical vector with data of the second sample. |
The classical LePage and 5 variants of it are performed, as proposed by Hussain and Tsagris (2025).
A matrix with 6 columns and two rows. The first row refers to the 6 test statistics and the second row to their corresponding p-values.
Abid Hussain and Michail Tsagris.
R implementation and documentation: Abid Hussain [email protected] and Michail Tsagris [email protected].
Hussain A. and Tsagris M. (2025). Modified Lepage-type test statistics for the weak null hypothesis. https://arxiv.org/pdf/2509.19126
x <- rnorm(30) y <- rnorm(40) lepage(x, y)x <- rnorm(30) y <- rnorm(40) lepage(x, y)